WebSkySZ — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- « previous
- so_pysm_models v0.4.dev210 »
- WebSkySZ

# WebSkySZ

class `so_pysm_models.` `WebSkySZ`(version='0.3', sz_type='kinetic', target_nside=4096, pixel_indices=None, mpi_comm=None, verbose=False)

  Bases: `object`

  Methods Summary

  `get_filename`() | Get SZ filenames for a websky version
  `signal`(nu, **kwargs) | Return map in uK_RJ at given frequency or array of frequencies

  Methods Documentation

  `get_filename`()

    Get SZ filenames for a websky version

  `signal`(nu, **kwargs)

    Return map in uK_RJ at given frequency or array of frequencies